function PR.GUI.RefreshSearchBox()
    -- turn PR.Config.Search.Ore into the full ore name
    local function getSearchOreName()
        for i = 1, PR.Ore.n do
            if PR.Ore[i].shortname == PR.Config.Search.Ore then
                return PR.Ore[i].name
            end
        end
        -- just in case
        PR.Config.Search.Ore = PR.Ore[1].shortname
        return PR.Ore[1].name
    end

    -- load system data, if not yet loaded
    PR.LoadSingleSystemData(PR.GUI.SystemData, PR.Config.Search.System)

    -- get search results
    local systable = PR.GUI.SystemData[PR.Config.Search.System][PR.Config.Search.Ore]
    local search_results = {} -- [1] text [2] sectorId
    if systable ~= nil then
        for sectorId, count in pairs(systable) do
            if count and count ~= 0 then
                table.insert(search_results, { "\t" .. PR.COLOR.WHITE ..
                    ShortLocationStr(sectorId) .. "  (" .. count .. " asteroids)" ..
                    PR.GetBotsSighted(sectorId) ..
                    PR.COLOR.TERMINATOR, sectorId })
            end
        end
    end
    -- sort search results by sector name.
    -- we could alternatively sort by asteroid count but this looks nicer
    table.sort(search_results,
        function(a, b) return gkmisc.strnatcasecmp(a[1], b[1]) < 0 end)

    -- output search results
    PR.GUI.ListedItems = {}
    local result_count = #search_results
    for i = 1, result_count do
        PR.GUI.DisplayPanel[i] = search_results[i][1]
        PR.GUI.ListedItems[i] = search_results[i][2]
    end
    if result_count == 1 then
        PR.GUI.DisplayPanel[1] = "\t" .. PR.COLOR.WHITE ..
            "No known asteroids" .. PR.COLOR.TERMINATOR
    end
    PR.GUI.MaxDisplayRows = result_count

    -- update button titles
    PR.GUI.Btn_Top2.title = getSearchOreName()
    PR.GUI.Btn_Top3.title = PR.Config.Search.Area
    PR.GUI.Btn_Top4.title = PR.GUI.SystemData[PR.Config.Search.System].systemname
end

-- sets PR.Config.Search.System to the next system id in the selected area
function PR.GUI.FetchNextSystem()
    local sysid = PR.Config.Search.System or 0
    repeat
        sysid = sysid + 1
        if sysid > PR.SystemOwnership.n then sysid = 0 end
    until PR.SystemOwnership[sysid] == PR.Config.Search.Area
    PR.Config.Search.System = sysid
end
