function PR.FormatId(roidId) -- add leading zeroes
    roidId = tonumber(roidId)
    return roidId and string.format("#%0" .. PR.MaxIdDigits .. "d", roidId) or "---"
end

function PR.FormatOreData(roidTable)
    local orestring = ""
    for i = 1, PR.Ore.n do
        local percentage = roidTable[PR.Ore[i].shortname] or 0
        if percentage > 0 then
            orestring = orestring .. " " .. PR.Ore[i].color .. PR.Ore[i].shortname ..
                ": " .. string.format("%.1f", percentage) .. " " ..
                PR.COLOR.TERMINATOR
        end
    end
    return orestring
end

function PR.DisplayScanData(roidTable, isnew)
    if (isnew or roidTable.Id ~= PR.LastDisplayedRoidId) then
        PR.LastDisplayedRoidId = roidTable.Id
        -- format scan data
        local msg = "Asteroid " .. PR.FormatId(roidTable.Id)
        local XPV = PR.GetXPV(roidTable)
        if XPV ~= 0 then
            if XPV > PR.Config.MinXPV then
                -- valid asteroid, display scan data
                msg = PR.COLOR.WHITE .. msg .. ": " .. PR.FormatOreData(roidTable)
                local mass = PR.GetMass(roidTable.Id)
                msg = msg .. PR.COLOR.WHITE .. "  XPV: " .. XPV
                if mass > 0 then
                    msg = msg .. PR.COLOR.LGRAY .. "  Mass: " .. mass .. " Pt"
                end
            else
                -- junk asteroid, don't display scan data, and if not fully
                -- verbose nothing at all except if newly scanned
                if not isnew and PR.Config.VerbosityLevel < 3 then return end
                msg = PR.COLOR.WHITE .. msg .. " is junk" -- @ " .. dist .. "m"
            end
        else
            -- unscanned asteroid
            local dist = comma_value(math.floor(GetTargetDistance() or 0))
            msg = PR.COLOR.GOLD .. msg .. " is unscanned @ " .. dist .. "m"
        end

        if isnew then
            msg = PR.COLOR.GOLD .. "New asteroid scanned: " .. PR.COLOR.TERMINATOR .. msg
        end
        PR.Print(msg .. PR.COLOR.TERMINATOR)
    end
end
