-- event handler for TARGET_SCANNED
function PR.TargetScanned(_, scaninfo, _, targetId)
    if PR.AutoScanTimer:IsActive() then PR.AutoScanTimer:Kill() end
    local dist = PR.TargetIsRoid()
    if dist == nil or scaninfo == nil or targetId == nil then
        if PR.AutoScanActive then PR.AutoScan() end
        return
    end
    PR.SingleSearchStop(true)

    local sectorId = GetCurrentSectorid()
    PR.LoadSector(sectorId)
    local is_scanned = PR.IsScanned(targetId)
    local roidTable = { Id = targetId }
    local mass_checked = false
    local mass_changed = false
    local ore_changed = false

    -- get target temp
    local temp
    if PR.MiningBeamEquipped then
        temp = tonumber(string.match(scaninfo, "Temperature: (.-) K"))
        -- amend asteroid info in GUI, if currently selected
        if PR.GUI.CurrentSectorShowing then
            local idx = tonumber(PR.GUI.DisplayPanel.VALUE)
            if idx and PR.GUI.ListedItems[idx] == targetId then
                local text = PR.GUI.DisplayPanel[idx]
                -- remove existing Temp: suffix
                local pos = text:find("  Temp:")
                if pos then text = text:sub(1, pos - 1) end
                -- add Temp: suffix
                if temp then
                    text = text .. PR.COLOR.WHITE .. "  Temp: " .. temp ..
                        " K" .. PR.COLOR.TERMINATOR
                end
                -- add Dist: suffix
                if dist then
                    text = text .. PR.COLOR.LGRAY .. " @ " ..
                        math.floor(dist) .. "m" .. PR.COLOR.TERMINATOR
                end
                PR.GUI.DisplayPanel[idx] = text
            end
        end
    end

    -- mass measurement while mining
    if PR.MassTestActive and targetId ~= PR.MassTarget then
        -- always cancel if target was switched
        PR.MassTestActive = false
    end
    if PR.MiningBeamEquipped and temp then
        if PR.MassScanCount > 0 and ((targetId ~= PR.MassTarget) or not
            (temp > PR.LastTemp)) then
            PR.MassScanCount = 0
            PR.MassTestActive = false
            if temp > 10 and PR.Config.VerbosityLevel > 2 then
                PR.Print("Mass measurement test failure.")
            end
        end
        if temp == 10 then
            PR.MassScanCount = 0
            if is_scanned then
                -- start mass test (only on scanned roids - don't need the
                -- complication of having mass but not mineral data in the db
                PR.MassTestActive = true
                PR.LastTemp = temp
                PR.MassTarget = targetId
                PR.MassScanMax = (GetActiveShipMaxCargo() -
                    GetActiveShipCargoCount()) > 60 and 10 or 5
            else
                PR.MassTestActive = false
            end
        elseif temp > 10 and PR.MassTestActive and targetId == PR.MassTarget then
            PR.LastTemp = temp
            PR.MassScanCount = PR.MassScanCount + 1
            -- print status message
            if PR.Config.VerbosityLevel > 2 then
                local info = "Asteroid mass measurement " ..
                    math.floor(PR.MassScanCount / PR.MassScanMax * 100) ..
                    "% completed."
                if PR.MassScanCount < PR.MassScanMax then
                    info = info .. " Do not change targets."
                end
                PR.Print(info)
            end
            -- mass test completed
            if PR.MassScanCount >= PR.MassScanMax then
                PR.MassScanCount = 0
                local tempdiff = temp - 10
                local mass = (PR.MassScanMax / tempdiff) * PR.BeamAvgHeat
                if mass > 0 then
                    -- add known mass to local RoidTable
                    roidTable.Pt = PR.GetMass(targetId)
                    mass_checked = true
                    -- save measured mass to local RoidTable
                    if roidTable.Pt == 0 then
                        roidTable.Pt = math.floor(mass)
                        mass_changed = true
                    elseif roidTable.Pt ~= mass then
                        -- calculate moving average - this is mainly for the
                        -- short measurements in low cargo ships because they
                        -- can vary quite a bit due to scan timing variance
                        -- having a bigger impact there
                        roidTable.Pt = math.floor((roidTable.Pt +
                            roidTable.Pt + mass) / 3)
                        mass_changed = true
                    end
                    if PR.Config.VerbosityLevel > 1 then
                        PR.Print("Asteroid mass determined to be " ..
                            roidTable.Pt .. " Pt.")
                    end
                elseif PR.Config.VerbosityLevel > 2 then
                    PR.Print("Mass measurement test failure.")
                end
                PR.MassTestActive = false
            end
        end
    end

    -- get ore data
    local is_new = false
    if not PR.ScannerEquipped or scaninfo:find("Object too far") then
        roidTable = PR.GetRoidAddMass(sectorId, roidTable)
    else
        is_new = not is_scanned
        -- add freshly scanned ore to local RoidTable
        for line in string.gmatch(scaninfo, "(.-)\n") do
            local longore, percentage = string.match(line, "(%w+) Ore: (.+)%%")
            if longore ~= nil and percentage ~= nil then
                roidTable[PR.GetOreNameShort(longore)] = tonumber(percentage)
            end
        end
        -- check if we already knew all the ore data
        ore_changed = PR.HasOreChanged(targetId, roidTable)
        -- add known mass to local RoidTable for display, if not measured above
        if not mass_checked then roidTable.Pt = PR.GetMass(targetId) end
        -- update MaxID
        if targetId > PR.Data.MaxId then
            PR.Data.MaxId = targetId
            PR.MaxIdDigits = PR.GetDigitCount(PR.Data.MaxId)
        end
    end
    -- output
    if PR.Config.VerbosityLevel > 1 then
        PR.DisplayScanData(roidTable, is_new)
    end

    -- update sector database, if anything changed
    if ore_changed or mass_changed then
        -- reset any existing ore data in database first
        if is_scanned and ore_changed then
            for i = 1, PR.Ore.n do
                PR.Data.RoidList[targetId][PR.Ore[i].shortname] = nil
            end
        end
        -- write new data to database
        PR.SetRoid(sectorId, roidTable)
    end
    -- perform related updates only if ore data changed
    if ore_changed then
        -- update unscanned count
        PR.UpdateUnscannedCount()
        -- update system summary ore data
        PR.SystemDataUpdate(sectorId)
    end
    -- if auto-scanning, trigger next scan after a short delay
    if PR.AutoScanActive then
        PR.AutoScanTimer:SetTimeout(PR.Config.AutoScanFrequency, PR.AutoScan)
    end
end
